<?php
/**
 * @package   ImpressPages
 */

namespace Plugin\Keywordlist;

class Model
{
    const TABLE_NAME = 'keywordlist';

    public static function setPageKey($pageId, $keywords, $description)
    {
        return ipDb()->upsert(self::TABLE_NAME, array('pageId' => $pageId), array('keywords' => $keywords, 'description' => $description));
    }

    public static function getPageKey($pageId)
    {
        return ipDb()->selectRow(self::TABLE_NAME, '*', array('pageId' => $pageId));
    }

    public static function removePageKey($pageId) {
        
        return ipDb()->delete(self::TABLE_NAME, array('pageId' => $pageId));
        
    }
    
    public static function getKeywordData()
    {
        $pageTable = ipTable('page');
        $keywordlistTable = ipTable(self::TABLE_NAME);
        $langCode = ipContent()->getCurrentLanguage()->getCode();
        $excludeFields = ' AND p.IsVisible = 1 AND p.IsDisabled = 0 AND p.IsDeleted = 0';
        $securedPages = ipGetOption('Keywordlist.securedPages') == 1 ? '' : 'AND p.IsSecured = 0';
        
        if (ipGetOption('Keywordlist.useMetadata') == 1) {
            
            $sql = "SELECT p.id, p.title, p.urlPath, p.keywords, p.description FROM $pageTable p WHERE p.languageCode = '$langCode' AND p.keywords != '' $excludeFields $securedPages";    
        
        } else {
            
            $sql = "SELECT p.id, p.title, p.urlPath, k.keywords, k.description FROM $pageTable p, $keywordlistTable k WHERE p.id = k.pageid AND p.languageCode = '$langCode' AND k.keywords != '' $excludeFields $securedPages";    
        
        }
        
        $keywordArray = array();
        $entries = array();
        $entries = ipDb()->fetchAll($sql);
        $existingChars = array();
        
        if (!empty($entries)) {
        
            // prepare array with keywords and pages 
            $keywordArray = array();
            
            $charSource = array('ä', 'ö', 'ü', 'ß', 'Ä', 'Ö', 'Ü'); 
            $charReplace = array('a', 'o', 'u', 's', 'A', 'O', 'U'); 
    
            foreach($entries as $entry) {
                
                $keywords = array_map('trim',explode(",",$entry['keywords']));
                
                foreach ($keywords as $keyword) {
                    
                    $firstChar = strtoupper(str_replace($charSource, $charReplace, mb_substr($keyword,0,1,'UTF-8')));
                    if (is_numeric($firstChar)) $firstChar = '0-9'; 
                    
                    $keywordArray[] = array('keyword' => $keyword,
                                            'char' =>  $firstChar,
                                            'id' => $entry['id'],
                                            'title' => $entry['title'],
                                            'description' => $entry['description'],
                                            'urlPath' => $entry['urlPath']);
                }
                
            }
            
            // sorting keywordarray depending first char of keyword    
            foreach ($keywordArray as $key => $row) {
               $char[$key] = $row['char'];
            }
            array_multisort($char, SORT_ASC, SORT_STRING, $keywordArray);
        
            $existingChars = array_unique($char);
        }
         
        $keywordData = array();
        
        $keywordData['entries'] = $keywordArray;
        $keywordData['chars'] = $existingChars;

        return $keywordData;    
    }
    
    
}
